summaryrefslogtreecommitdiffstats
path: root/libtdepim/tests/testdistrlist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/tests/testdistrlist.cpp')
-rw-r--r--libtdepim/tests/testdistrlist.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libtdepim/tests/testdistrlist.cpp b/libtdepim/tests/testdistrlist.cpp
index f588f9a9..f6664701 100644
--- a/libtdepim/tests/testdistrlist.cpp
+++ b/libtdepim/tests/testdistrlist.cpp
@@ -42,8 +42,8 @@ using KPIM::DistributionList;
int main(int argc, char *argv[])
{
// Use another directory than the real one, just to keep things clean
- // KDEHOME needs to be writable though, for a ksycoca database
- setenv( "KDEHOME", TQFile::encodeName( TQDir::homeDirPath() + "/.kde-testdistrlist" ), true );
+ // TDEHOME needs to be writable though, for a ksycoca database
+ setenv( "TDEHOME", TQFile::encodeName( TQDir::homeDirPath() + "/.kde-testdistrlist" ), true );
setenv( "KDE_FORK_SLAVES", "yes", true ); // simpler, for the final cleanup
KApplication::disableAutoDcopRegistration();
@@ -150,7 +150,7 @@ void TestDistrList::cleanup()
ab->clear();
KABC::StdAddressBook::close();
- TQString kdehome = TQFile::decodeName( getenv("KDEHOME") );
+ TQString kdehome = TQFile::decodeName( getenv("TDEHOME") );
KURL urlkdehome; urlkdehome.setPath( kdehome );
// don't use KIO::NetAccess here since it needs X
// KIO::NetAccess::del( urlkdehome, 0 )i;